@@ -17,7 +17,9 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
+
 """Cosmos module wrapping the public and private key cryptography and ledger api."""
+
 # pylint: disable = import-outside-toplevel, possibly-unused-variable
 import base64
 import gzip
@@ -98,7 +100,7 @@ def lazy_load():  # Python caches all imported modules
     return locals()
 
 
-_default_logger = logging.getLogger(__name__)
+_default_logger = logging.getLogger("aea.ledger_apis.cosmos")
 
 _COSMOS = "cosmos"
 TESTNET_NAME = "testnet"
@@ -1542,6 +1544,25 @@ class _CosmosApi(LedgerApi):
         """
         raise NotImplementedError
 
+    def send_signed_transactions(
+        self,
+        signed_transactions: List[JSONLike],
+        raise_on_try: bool = False,
+        **kwargs: Any,
+    ) -> Optional[List[str]]:
+        """
+        Atomically send multiple of transactions.
+
+        This operation is not supported for cosmos.
+
+        :param signed_transactions: the raw signed transactions to bundle together and send.
+        :param raise_on_try: whether the method will raise or log on error.
+        :param kwargs: the keyword arguments.
+        """
+        raise NotImplementedError(  # pragma: nocover
+            f"Sending a bundle of transactions is not supported for the {self.identifier} plugin"
+        )
+
 
 class CosmosApi(_CosmosApi, CosmosHelper):
     """Class to interact with the Cosmos SDK via a HTTP APIs."""
